==> pjsip-2.4.5.tgz: include/pjlib.h <==
/* $Id: pjlib.h 3553 2011-05-05 06:14:19Z nanang $ */
/* 
 * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
 * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef __PJLIB_H__
#define __PJLIB_H__

/**
 * @file pjlib.h
 * @brief Include all PJLIB header files.
 */

#include <pj/activesock.h>
#include <pj/addr_resolv.h>
#include <pj/array.h>
#include <pj/assert.h>
#include <pj/ctype.h>
#include <pj/errno.h>
#include <pj/except.h>
#include <pj/fifobuf.h>
#include <pj/file_access.h>
#include <pj/file_io.h>
#include <pj/guid.h>
#include <pj/hash.h>
#include <pj/ioqueue.h>
#include <pj/ip_helper.h>
#include <pj/list.h>
#include <pj/lock.h>
#include <pj/log.h>
#include <pj/math.h>
#include <pj/os.h>
#include <pj/pool.h>
#include <pj/pool_buf.h>
#include <pj/rand.h>
#include <pj/rbtree.h>
#include <pj/sock.h>
#include <pj/sock_qos.h>
#include <pj/sock_select.h>
#include <pj/ssl_sock.h>
#include <pj/string.h>
#include <pj/timer.h>
#include <pj/unicode.h>

#include <pj/compat/high_precision.h>

#endif  /* __PJLIB_H__ */

==> pjsip-2.16.tgz: include/pjlib.h <==
/* 
 * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
 * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef __PJLIB_H__
#define __PJLIB_H__

/**
 * @file pjlib.h
 * @brief Include all PJLIB header files.
 */

#include <pj/activesock.h>
#include <pj/addr_resolv.h>
#include <pj/argparse.h>
#include <pj/array.h>
#include <pj/assert.h>
#include <pj/atomic_queue.h>
#include <pj/ctype.h>
#include <pj/errno.h>
#include <pj/except.h>
#include <pj/fifobuf.h>
#include <pj/file_access.h>
#include <pj/file_io.h>
#include <pj/guid.h>
#include <pj/hash.h>
#include <pj/ioqueue.h>
#include <pj/ip_helper.h>
#include <pj/list.h>
#include <pj/lock.h>
#include <pj/log.h>
#include <pj/math.h>
#include <pj/os.h>
#include <pj/pool.h>
#include <pj/pool_buf.h>
#include <pj/rand.h>
#include <pj/rbtree.h>
#include <pj/atomic_slist.h>
#include <pj/sock.h>
#include <pj/sock_qos.h>
#include <pj/sock_select.h>
#include <pj/ssl_sock.h>
#include <pj/string.h>
#include <pj/timer.h>
#include <pj/unicode.h>
#include <pj/unittest.h>

#include <pj/compat/high_precision.h>

#endif  /* __PJLIB_H__ */
